@@ -1,4 +1,4 @@
-from bjerrum import bjerrum
+from .bjerrum import bjerrum
 from math import pi
 
 avo = 6.02e23
@@ -12,5 +12,5 @@ def I(salts):
 def debye(salts, epsr=74.5, T=310, reduced=False):
     length = 8 * pi * bjerrum(epsr, T, reduced=False) * I(salts) * avo * 1e3
     length = length ** -0.5
-    print "The Debye length is {}".format(length)
+    print(("The Debye length is {}".format(length)))
     return length
